#!/usr/bin/env python

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

__copyright__ = '2012 Canonical Ltd - ' + \
                'Sergio Schvezov <sergio.schvezov@canonical.com>'

import os
import logging
import errno
import re
import fileinput

logging.basicConfig(level=logging.DEBUG)
logger = logging.getLogger()
logger.name = 'H40native_hack'


def fix_changelog():
    """If the package is originally quilt that means that the version
    is debianized and also needs fixing.
    """
    logger.info('Fixing version in changelog')
    changelog_file_path = 'debian/changelog'
    with open(changelog_file_path, 'r') as format_file:
        text = format_file.read()
        text = re.sub(r'-[0-9]*ubuntu[0-9]*\)', ')', text)
    with open(changelog_file_path, 'w') as format_file:
        format_file.write(text)


def replace_quilt_with_native(format_file_path):
    """Like `sed -i s/quilt/native/g`."""
    logger.info('Editing debian/source/format s/quilt/native/ (as necessary)')
    for line in fileinput.FileInput(format_file_path, inplace=1):
        line = line.replace('quilt', 'native')
        print line.strip()


def check_and_create_format_dir():
    """Checks for format file, creates it if it doesn't exist as
    (3.0) native or replaces 'quilt' with 'native'.
    '"""
    format_file_path = 'debian/source/format'
    if os.path.exists(format_file_path):
        replace_quilt_with_native(format_file_path)
    else:
        try:
            os.makedirs(os.path.dirname(format_file_path))
        except OSError, e:
            if e.errno != errno.EEXIST:
                raise
        with open(format_file_path, 'w') as format_file:
            format_file.write('3.0 (native)\n')


if __name__ == '__main__':
    logger.debug('Current directory' + os.path.abspath('.'))
    check_and_create_format_dir()
    fix_changelog()
