# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

__copyright__ = '2012 Canonical Ltd - ' + \
                'Sergio Schvezov <sergio.schvezov@canonical.com>'

import subprocess

from mock import patch
from testtools import TestCase
from testtools.matchers import raises

from pbuilderjenkins.pbuilderjenkins import bzr_build


class BazaarBuildTest(TestCase):

    def setUp(self):
        super(BazaarBuildTest, self).setUp()

    @patch('subprocess.check_call', create=True)
    def test_shall_execute_bzr_build(self, check_call_mock):
        """
        Invoking bzr_build with a recipe and work argument MUST
        lead to a shell call of bzr build with those arguments.
        """
        # Given
        target = 'work'
        recipe = 'file.recipe'
        # When
        bzr_build(recipe, target)
        # Then
        check_call_mock.assert_called_once_with(['bzr',
                                                 'build',
                                                 recipe,
                                                 target])

    @patch('subprocess.check_call', create=True)
    def test_raise_subprocess_exception_on_failed_call(self, check_call_mock):
        """
        An shell error after invoking bzr_build MUST
        raise a CalledProcessError exception.
        """
        # Given
        target = 'work'
        recipe = 'file.recipe'
        check_call_mock.side_effect = \
            subprocess.CalledProcessError(1, 'bzr build')
        # When/Then
        self.assertThat(lambda: bzr_build(recipe, target),
                        raises(RuntimeError))
