# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

__copyright__ = '2014 Canonical Ltd - ' + \
                'Francis Ginther <francis.ginther@canonical.com>'

from mock import MagicMock
from mock import patch
import os
from testtools import TestCase
#from testtools import skip
#from testtools.matchers import raises

from pbuilderjenkins.pbuilderjenkins import ChrootPBuilder


class ChrootPBuilderTest(TestCase):

    def setUp(self):
        super(ChrootPBuilderTest, self).setUp()
        self.main_branch = 'lp:main'
        self.packaging_branch = 'lp:packaging'
        self.target_branch = 'lp:merge'

    @patch('os.getcwd')
    def test_init(self, getcwd_mock):
        '''Verifies the pbuilder paths are initialized correctly.'''
        getcwd_mock.return_value = '/workspace/path'
        builder = ChrootPBuilder(self.main_branch)
        self.assertEqual('/workspace/path/work/results', builder._result_dir)
        self.assertEqual('/var/cache/pbuilder/base.tgz', builder._basetgz)
        self.assertEqual('/workspace/path/ReportDir', builder._input_file)
        self.assertEqual('/workspace/path/work/output', builder._output_dir)

    @patch('os.getcwd')
    @patch('os.path.exists')
    @patch('subprocess.check_call')
    def test_build(self, check_call_mock, exists_mock, getcwd_mock):
        '''Verifies all of the paths passed to the build command.'''
        getcwd_mock.return_value = '/workspace/path'
        exists_mock.return_value = True
        builder = ChrootPBuilder(self.main_branch)
        builder._build(None)
        self.assertIn('--inputfile /workspace/path/ReportDir',
                      check_call_mock.call_args[0][0])
        self.assertIn('--bindmounts /workspace/path/work/results',
                      check_call_mock.call_args[0][0])
        self.assertIn('--basetgz /var/cache/pbuilder/base.tgz',
                      check_call_mock.call_args[0][0])
        self.assertIn('--buildresult /workspace/path/work/output',
                      check_call_mock.call_args[0][0])
        self.assertIn('--orig-dir /workspace/path/orig-dir',
                      check_call_mock.call_args[0][0])
        self.assertIn('--build-dir /workspace/path/build-dir',
                      check_call_mock.call_args[0][0])

    @patch('os.getcwd')
    @patch('os.path.exists')
    @patch('subprocess.check_call')
    def test_build_parallel_default(self, check_call_mock, exists_mock,
                                    getcwd_mock):
        '''Verifies the default parallel build environment setting.'''
        getcwd_mock.return_value = '/workspace/path'
        exists_mock.return_value = True
        builder = ChrootPBuilder(self.main_branch)
        builder._build(None)
        self.assertEqual('parallel=1', os.environ['DEB_BUILD_OPTIONS'])

    @patch('os.getcwd')
    @patch('os.path.exists')
    @patch('subprocess.check_call')
    def test_build_parallel_four(self, check_call_mock, exists_mock,
                                 getcwd_mock):
        '''Verifies a specific parallel build environment setting.'''
        getcwd_mock.return_value = '/workspace/path'
        exists_mock.return_value = True
        builder = ChrootPBuilder(self.main_branch, parallel_jobs=4)
        builder._build(None)
        self.assertEqual('parallel=4', os.environ['DEB_BUILD_OPTIONS'])

    @patch('os.getcwd')
    @patch('os.mkdir')
    @patch('__builtin__.open')
    @patch('os.chmod')
    def test_workdir_setup(self, chmod_mock, open_mock, mkdir_mock,
                           getcwd_mock):
        '''Verifies the contents of the pbuilder input file.'''
        getcwd_mock.return_value = '/workspace/path'
        file_mock = MagicMock()
        file_mock.write = MagicMock()
        context_manager_mock = MagicMock()
        context_manager_mock.__enter__ = MagicMock()
        context_manager_mock.__enter__.return_value = file_mock
        context_manager_mock.__exit__ = MagicMock()
        open_mock.return_value = context_manager_mock
        builder = ChrootPBuilder(self.main_branch)
        builder._workdir_setup()
        self.assertEqual('RESULT_DIR=/workspace/path/work/results\n',
                         file_mock.write.call_args[0][0])
