# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

__copyright__ = '2012 Canonical Ltd - ' + \
                'Sergio Schvezov <sergio.schvezov@canonical.com>'

from testtools import TestCase
from testtools.matchers import Equals
from testtools.matchers import raises

from pbuilderjenkins.pbuilderjenkins import create_recipe


class RecipesTest(TestCase):

    def setUp(self):
        super(RecipesTest, self).setUp()
        self.main_branch = 'lp:main'
        self.packaging_branch = 'lp:packaging'
        self.target_branch = 'lp:merge'

    def test_build_recipe_with_only_main_branch(self):
        """
        Creating a build recipe with only the main branch MUST
        format a recipe with a main branch and no target nor packaging branch.
        """
        expected_recipe = '# bzr-builder format 0.4\n'
        expected_recipe += self.main_branch
        expected_recipe += '\n# No target branch\n'
        expected_recipe += '# No packaging branch\n'
        self.assertThat(create_recipe(self.main_branch),
                        Equals(expected_recipe))

    def test_build_recipe_with_main_and_packaging_branch(self):
        """
        Creating a build recipe with a main and packaging branch MUST
        format a recipe with a main and packaging branch and no target branch.
        """
        expected_recipe = '# bzr-builder format 0.4\n'
        expected_recipe += self.main_branch
        expected_recipe += '\n# No target branch\n'
        expected_recipe += 'nest-part ubuntu '
        expected_recipe += self.packaging_branch + ' debian\n'
        self.assertThat(create_recipe(self.main_branch, self.packaging_branch),
                        Equals(expected_recipe))

    def test_build_recipe_with_main_and_packaging_and_target_branch(self):
        """
        Creating a build recipe with a main, packaging and target branch MUST
        format a recipe with a main, packaging and target branch.
        """
        expected_recipe = '# bzr-builder format 0.4\n'
        expected_recipe += self.main_branch
        expected_recipe += '\nmerge target ' + self.target_branch
        expected_recipe += '\nnest-part ubuntu '
        expected_recipe += self.packaging_branch + ' debian\n'
        self.assertThat(create_recipe(self.main_branch, self.packaging_branch, self.target_branch),
                        Equals(expected_recipe))

    def test_build_recipe_with_main_and_target_branch(self):
        """
        Creating a build recipe with a main  and target branch MUST
        format a recipe with a main and target branch but no packaging branch.
        """
        expected_recipe = '# bzr-builder format 0.4\n'
        expected_recipe += self.main_branch
        expected_recipe += '\nmerge target ' + self.target_branch
        expected_recipe += '\n# No packaging branch\n'
        self.assertThat(create_recipe(self.main_branch, target_branch=self.target_branch),
                        Equals(expected_recipe))

    def test_build_recipe_with_no_main_and_with_target_branch(self):
        """Creating a recipe with no main MUST raise a TypeError."""
        self.assertThat(lambda: create_recipe(target_branch=self.target_branch),
                        raises(TypeError))
